ImageScanResult class

Result from scanning documents as images.

Constructors

ImageScanResult({required List<String> images})
const
ImageScanResult.fromPlatformData(dynamic data)
Creates an ImageScanResult from the raw platform channel data.
factory

Properties

count → int
Number of scanned images.
no setter
hashCode → int
The hash code for this object.
no setterinherited
images → List<String>
List of file paths (iOS) or content URIs (Android) for the scanned images.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited