PdfScanResult class

Result from scanning documents as a PDF.

Constructors

PdfScanResult({required String pdfUri, int pageCount = 0})
const
PdfScanResult.fromPlatformData(dynamic data)
Creates a PdfScanResult from the raw platform channel data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageCount → int
Number of pages in the PDF. Only available on Android; defaults to 0 on iOS.
final
pdfUri → String
File path (iOS) or content URI (Android) of the generated PDF.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited