FlutterDocScannerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterDocScannerPlatform
Implementers

Constructors

FlutterDocScannerPlatform()
Constructs a FlutterDocScannerPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
getScanDocuments(int page) Future
Scans documents and returns raw platform data.
getScanDocumentsUri(int page) Future
Scans documents and returns URIs (Android only).
getScannedDocumentAsImages(int page, String imageFormat, double quality) Future
Scans documents and returns raw image data from the platform.
getScannedDocumentAsPdf(int page) Future
Scans documents and returns raw PDF data from the platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterDocScannerPlatform
The default instance of FlutterDocScannerPlatform to use.
getter/setter pair