MethodChannelFlutterDocScanner class

An implementation of FlutterDocScannerPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
override
getScanDocuments(int page) Future
Scans documents and returns raw platform data.
override
getScanDocumentsUri(int page) Future
Scans documents and returns URIs (Android only).
override
getScannedDocumentAsImages(int page, String imageFormat, double quality) Future
Scans documents and returns raw image data from the platform.
override
getScannedDocumentAsPdf(int page) Future
Scans documents and returns raw PDF data from the platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited