ImageFormat enum
Image format for scanned document images.
On Android, ML Kit always returns JPEG regardless of this setting. On iOS, this controls whether images are saved as PNG or JPEG.
Values
- png → const ImageFormat
-
PNG format. Lossless, larger file size. Default on iOS.
- jpeg → const ImageFormat
-
JPEG format. Lossy, smaller file size. Default on Android.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ImageFormat> - A constant List of the values in this enum, in order of their declaration.